@@ -35,6 +35,7 @@ class Mundo(object):
         self.camara = camara.Camara(self)
 
         eventos.actualizar.conectar(self.actualizar_simuladores)
+        eventos.actualizar_pausado.conectar(self.actualizar_simuladores_pausado)
         self.fisica = fisica.Fisica(motor.obtener_area(), gravedad=gravedad)
         self.escena_actual = None
 
@@ -47,9 +48,14 @@ class Mundo(object):
         self.fisica.actualizar()
         self.colisiones.verificar_colisiones()
 
+    def actualizar_simuladores_pausado(self, evento):
+        self.tweener.update(0)
+        self.tareas.actualizar(1/60.0)
+        self.fisica.actualizar(velocidad=0)
+        self.colisiones.verificar_colisiones()
+
     def terminar(self):
-        import sys
-        sys.exit(0)
+        self.motor.terminar()
 
     def ejecutar_bucle_principal(self, ignorar_errores=False):
         "Mantiene en funcionamiento el motor completo."
